@@ -1,5 +1,4 @@
 import copy
-from typing import List
 
 from ...library import Library
 from ...model import Block, Entry
@@ -9,7 +8,7 @@ from ..middleware import BlockMiddleware
 class KeepFieldsInEntry(BlockMiddleware):
     """Keep the fields of an entry according to a custom list of field keys provided by user."""
 
-    def __init__(self, entry_type: str, keep_field_keys: List[str], allow_inplace_modification: bool = True):
+    def __init__(self, entry_type: str, keep_field_keys: list[str], allow_inplace_modification: bool = True):
         super().__init__(allow_inplace_modification=allow_inplace_modification, allow_parallel_execution=True)
 
         self.entry_type = entry_type
